# afw
Tests Automation Framework

# Check Python installation
python3 --version

# If Python is not installed, install it using Homebrew
brew install python

# Create a virtual environment
python3 -m venv venv

# Activate the virtual environment
source venv/bin/activate  # On macOS and Linux
# .\venv\Scripts\activate  # On Windows

# Install dependencies
pip install -r requirements.txt
